GlassXTheme class

Provides GlassX-aware ThemeData helpers so that glass widgets automatically adapt to the app's light / dark theme.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

borderForBrightness(Brightness brightness) Color
Returns an appropriate glass border colour based on brightness.
cardDecoration(GlassXConfig config) BoxDecoration
Creates a BoxDecoration for an elevated glass card (includes shadow).
fromTheme(ThemeData theme, {GlassXConfig? base}) GlassXConfig
Derives a GlassXConfig from the provided ThemeData, preserving all other fields from base.
glassDecoration(GlassXConfig config) BoxDecoration
Creates a BoxDecoration representing the glass surface using config.
tintForBrightness(Brightness brightness, {double opacity = 0.15}) Color
Returns an appropriate glass tint colour based on brightness.